@@ -1,13 +1,10 @@
-require File.expand_path('../example_setup', __FILE__)
-
+require 'bundler/setup'
 require 'flipper'
 
-adapter = Flipper::Adapters::Memory.new
-flipper = Flipper.new(adapter)
-logging = flipper[:logging]
+logging = Flipper[:logging]
 
 perform_test = lambda do |number|
-  logging.enable flipper.time(number)
+  logging.enable_percentage_of_time number
 
   total = 100_000
   enabled = []
