@@ -1,10 +1,4 @@
-require 'pathname'
-require 'logger'
-
-root_path = Pathname(__FILE__).dirname.join('..').expand_path
-lib_path  = root_path.join('lib')
-$:.unshift(lib_path)
-
+require 'bundler/setup'
 require 'redis'
 require 'rollout'
 require 'flipper'
