@@ -1,7 +1,7 @@
 require "forwardable"
 
 module Flipper
-  extend self # rubocop:disable Style/ModuleFunction
+  extend self
   extend Forwardable
 
   # Private: The namespace for all instrumented events.
@@ -16,7 +16,7 @@ module Flipper
   # Public: Configure flipper.
   #
   #   Flipper.configure do |config|
-  #     config.default { ... }
+  #     config.adapter { ... }
   #   end
   #
   # Yields Flipper::Configuration instance.
@@ -65,7 +65,8 @@ module Flipper
                  :time, :percentage_of_time,
                  :features, :feature, :[], :preload, :preload_all,
                  :adapter, :add, :exist?, :remove, :import,
-                 :memoize=, :memoizing?
+                 :memoize=, :memoizing?,
+                 :sync, :sync_secret # For Flipper::Cloud. Will error for OSS Flipper.
 
   # Public: Use this to register a group by name.
   #
@@ -151,6 +152,7 @@ require 'flipper/feature'
 require 'flipper/gate'
 require 'flipper/instrumenters/memory'
 require 'flipper/instrumenters/noop'
+require 'flipper/identifier'
 require 'flipper/middleware/memoizer'
 require 'flipper/middleware/setup_env'
 require 'flipper/registry'
@@ -162,3 +164,5 @@ require 'flipper/types/percentage'
 require 'flipper/types/percentage_of_actors'
 require 'flipper/types/percentage_of_time'
 require 'flipper/typecast'
+
+require "flipper/railtie" if defined?(Rails::Railtie)
