@@ -59,7 +59,7 @@ module Flipper
           unless @feature_class.where(key: feature.key).first
             begin
               @feature_class.create! { |f| f.key = feature.key }
-            rescue ActiveRecord::RecordNotUnique
+            rescue ::ActiveRecord::RecordNotUnique
             end
           end
         end
@@ -125,7 +125,9 @@ module Flipper
       # Returns true.
       def enable(feature, gate, thing)
         case gate.data_type
-        when :boolean, :integer
+        when :boolean
+          set(feature, gate, thing, clear: true)
+        when :integer
           set(feature, gate, thing)
         when :set
           enable_multi(feature, gate, thing)
@@ -165,8 +167,10 @@ module Flipper
 
       private
 
-      def set(feature, gate, thing)
+      def set(feature, gate, thing, options = {})
+        clear_feature = options.fetch(:clear, false)
         @gate_class.transaction do
+          clear(feature) if clear_feature
           @gate_class.where(feature_key: feature.key, key: gate.key).destroy_all
           @gate_class.create! do |g|
             g.feature_key = feature.key
@@ -215,3 +219,7 @@ module Flipper
     end
   end
 end
+
+Flipper.configure do |config|
+  config.adapter { Flipper::Adapters::ActiveRecord.new }
+end
