@@ -84,7 +84,10 @@ module Flipper
       def enable(feature, gate, thing)
         @store.transaction do
           case gate.data_type
-          when :boolean, :integer
+          when :boolean
+            clear_gates(feature)
+            write key(feature, gate), thing.value.to_s
+          when :integer
             write key(feature, gate), thing.value.to_s
           when :set
             set_add key(feature, gate), thing.value.to_s
@@ -213,3 +216,7 @@ module Flipper
     end
   end
 end
+
+Flipper.configure do |config|
+  config.adapter { Flipper::Adapters::PStore.new }
+end
