@@ -5,10 +5,10 @@ module Flipper
   module UI
     module Actions
       class AddFeature < UI::Action
-        route %r{features/new/?\Z}
+        route %r{\A/features/new/?\Z}
 
         def get
-          unless Flipper::UI.feature_creation_enabled
+          unless Flipper::UI.configuration.feature_creation_enabled
             status 403
 
             breadcrumb 'Home', '/'
