@@ -10,8 +10,21 @@ module Flipper
 
         def get
           @page_title = 'Features'
+          keys = flipper.features.map(&:key)
+          descriptions = if Flipper::UI.configuration.show_feature_description_in_list?
+            Flipper::UI.configuration.descriptions_source.call(keys)
+          else
+            {}
+          end
+
           @features = flipper.features.map do |feature|
-            Decorators::Feature.new(feature)
+            decorated_feature = Decorators::Feature.new(feature)
+
+            if Flipper::UI.configuration.show_feature_description_in_list?
+              decorated_feature.description = descriptions[feature.key]
+            end
+
+            decorated_feature
           end.sort
 
           @show_blank_slate = @features.empty?
