@@ -5,7 +5,7 @@ module Flipper
   module UI
     module Actions
       class Home < UI::Action
-        route %r{/?\Z}
+        route %r{\A/?\Z}
 
         def get
           redirect_to '/features'
