@@ -3,11 +3,7 @@ require 'flipper/ui/configuration/option'
 module Flipper
   module UI
     class Configuration
-      attr_reader :actors,
-                  :delete,
-                  :groups,
-                  :percentage_of_actors,
-                  :percentage_of_time
+      attr_reader :delete
 
       attr_accessor :banner_text,
                     :banner_class
@@ -30,11 +26,24 @@ module Flipper
       # won't see a videoclip of Taylor Swift when there aren't any features
       attr_accessor :fun
 
+      # Public: Tired of seeing the awesome message about Cloud? Set this to
+      # false and it will go away. Defaults to true.
+      attr_accessor :cloud_recommendation
+
       # Public: What should show up in the form to add actors. This can be
       # different per application since flipper_id's can be whatever an
       # application needs. Defaults to "a flipper id".
       attr_accessor :add_actor_placeholder
 
+      # Public: If you set this, Flipper::UI will fetch descriptions
+      # from your external source. Descriptions for `features` will be shown on `feature`
+      # page, and optionally the `features` pages. Defaults to empty block.
+      attr_accessor :descriptions_source
+
+      # Public: Should feature descriptions be show on the `features` list page.
+      # Default false. Only works when using descriptions.
+      attr_accessor :show_feature_description_in_list
+
       VALID_BANNER_CLASS_VALUES = %w(
         danger
         dark
@@ -46,18 +55,27 @@ module Flipper
         warning
       ).freeze
 
+      DEFAULT_DESCRIPTIONS_SOURCE = ->(_keys) { {} }
+
       def initialize
-        @actors = Option.new("Actors", "Enable actors using the form above.")
-        @groups = Option.new("Groups", "Enable groups using the form above.")
-        @percentage_of_actors = Option.new("Percentage of Actors", "Percentage of actors functions independently of percentage of time. If you enable 50% of Actors and 25% of Time then the feature will always be enabled for 50% of users and occasionally enabled 25% of the time for everyone.") # rubocop:disable Metrics/LineLength
-        @percentage_of_time = Option.new("Percentage of Time", "Percentage of actors functions independently of percentage of time. If you enable 50% of Actors and 25% of Time then the feature will always be enabled for 50% of users and occasionally enabled 25% of the time for everyone.") # rubocop:disable Metrics/LineLength
-        @delete = Option.new("Danger Zone", "Deleting a feature removes it from the list of features and disables it for everyone.") # rubocop:disable Metrics/LineLength
+        @delete = Option.new("Danger Zone", "Deleting a feature removes it from the list of features and disables it for everyone.")
         @banner_text = nil
         @banner_class = 'danger'
         @feature_creation_enabled = true
         @feature_removal_enabled = true
         @fun = true
+        @cloud_recommendation = true
         @add_actor_placeholder = "a flipper id"
+        @descriptions_source = DEFAULT_DESCRIPTIONS_SOURCE
+        @show_feature_description_in_list = false
+      end
+
+      def using_descriptions?
+        @descriptions_source != DEFAULT_DESCRIPTIONS_SOURCE
+      end
+
+      def show_feature_description_in_list?
+        using_descriptions? && @show_feature_description_in_list
       end
 
       def banner_class=(value)
