@@ -4,53 +4,79 @@ RSpec.describe Flipper::Api::V1::Actions::PercentageOfActorsGate do
   let(:app) { build_api(flipper) }
 
   describe 'enable' do
-    context 'for feature with slash in name' do
-      before do
-        flipper["my/feature"].disable
-        post '/features/my/feature/percentage_of_actors', percentage: '10'
-      end
-
+    shared_examples 'gates with percentage' do
       it 'enables gate for feature' do
-        expect(flipper["my/feature"].enabled_gate_names).to include(:percentage_of_actors)
+        expect(flipper[path].enabled_gate_names).to include(:percentage_of_actors)
       end
 
-      it 'returns decorated feature with gate enabled for 10 percent of actors' do
+      it 'returns decorated feature with gate enabled for a percent of actors' do
         gate = json_response['gates'].find { |gate| gate['name'] == 'percentage_of_actors' }
-        expect(gate['value']).to eq('10')
+        expect(gate['value']).to eq(percentage)
+      end
+    end
+
+    context 'for feature with slash in name' do
+      let(:path) { 'my/feature' }
+
+      before do
+        flipper[path].disable
+        post "/features/#{path}/percentage_of_actors", percentage: percentage
+      end
+
+      context 'with integer percentage' do
+        let(:percentage) { '10' }
+
+        it_behaves_like 'gates with percentage'
+      end
+
+      context 'with decimal percentage' do
+        let(:percentage) { '0.05' }
+
+        it_behaves_like 'gates with percentage'
       end
     end
 
     context 'url-encoded request' do
+      let(:path) { :my_feature }
+
       before do
         flipper[:my_feature].disable
-        post '/features/my_feature/percentage_of_actors', percentage: '10'
+        post "/features/#{path}/percentage_of_actors", percentage: percentage
       end
 
-      it 'enables gate for feature' do
-        expect(flipper[:my_feature].enabled_gate_names).to include(:percentage_of_actors)
+      context 'with integer percentage' do
+        let(:percentage) { '10' }
+
+        it_behaves_like 'gates with percentage'
       end
 
-      it 'returns decorated feature with gate enabled for 10 percent of actors' do
-        gate = json_response['gates'].find { |gate| gate['name'] == 'percentage_of_actors' }
-        expect(gate['value']).to eq('10')
+      context 'with decimal percentage' do
+        let(:percentage) { '0.05' }
+
+        it_behaves_like 'gates with percentage'
       end
     end
 
     context 'json request' do
+      let(:path) { :my_feature }
+
       before do
         flipper[:my_feature].disable
-        post '/features/my_feature/percentage_of_actors',
-             JSON.generate(percentage: '10'),
+        post "/features/#{path}/percentage_of_actors",
+             JSON.generate(percentage: percentage),
              'CONTENT_TYPE' => 'application/json'
       end
 
-      it 'enables gate for feature' do
-        expect(flipper[:my_feature].enabled_gate_names).to include(:percentage_of_actors)
+      context 'with integer percentage' do
+        let(:percentage) { '10' }
+
+        it_behaves_like 'gates with percentage'
       end
 
-      it 'returns decorated feature with gate enabled for 10 percent of actors' do
-        gate = json_response['gates'].find { |gate| gate['name'] == 'percentage_of_actors' }
-        expect(gate['value']).to eq('10')
+      context 'with decimal percentage' do
+        let(:percentage) { '0.05' }
+
+        it_behaves_like 'gates with percentage'
       end
     end
   end
@@ -113,7 +139,7 @@ RSpec.describe Flipper::Api::V1::Actions::PercentageOfActorsGate do
     end
   end
 
-  describe 'percentage parameter not an integer' do
+  describe 'percentage parameter not a number' do
     before do
       flipper[:my_feature].disable
       post '/features/my_feature/percentage_of_actors', percentage: 'foo'
