@@ -62,7 +62,7 @@ RSpec.describe Flipper::UI::Actions::Features do
         end
 
         it 'renders template' do
-          expect(last_response.body).to include('There aren\'t any features to configure.')
+          expect(last_response.body).to include('You have not added any features to configure yet.')
         end
       end
     end
@@ -111,12 +111,10 @@ RSpec.describe Flipper::UI::Actions::Features do
             expect(flipper.features.map(&:key)).to eq([])
           end
 
-          # rubocop:disable Metrics/LineLength
           it 'redirects back to feature' do
             expect(last_response.status).to be(302)
             expect(last_response.headers['Location']).to eq('/features/new?error=%22%22+is+not+a+valid+feature+name.')
           end
-          # rubocop:enable Metrics/LineLength
         end
 
         context 'nil feature name' do
@@ -126,12 +124,10 @@ RSpec.describe Flipper::UI::Actions::Features do
             expect(flipper.features.map(&:key)).to eq([])
           end
 
-          # rubocop:disable Metrics/LineLength
           it 'redirects back to feature' do
             expect(last_response.status).to be(302)
             expect(last_response.headers['Location']).to eq('/features/new?error=%22%22+is+not+a+valid+feature+name.')
           end
-          # rubocop:enable Metrics/LineLength
         end
       end
     end
