@@ -22,36 +22,6 @@ RSpec.describe Flipper::UI::Decorators::Feature do
     end
   end
 
-  describe '#as_json' do
-    before do
-      @result = subject.as_json
-    end
-
-    it 'returns Hash' do
-      expect(@result).to be_instance_of(Hash)
-    end
-
-    it 'includes id' do
-      expect(@result['id']).to eq('some_awesome_feature')
-    end
-
-    it 'includes pretty name' do
-      expect(@result['name']).to eq('Some Awesome Feature')
-    end
-
-    it 'includes state' do
-      expect(@result['state']).to eq('off')
-    end
-
-    it 'includes gates' do
-      gates = subject.gates.map do |gate|
-        value = subject.gate_values[gate.key]
-        Flipper::UI::Decorators::Gate.new(gate, value).as_json
-      end
-      expect(@result['gates']).to eq(gates)
-    end
-  end
-
   describe '#<=>' do
     let(:on) do
       flipper.enable(:on_a)
