@@ -1,4 +1,5 @@
 require 'helper'
+require 'flipper/cloud'
 
 RSpec.describe Flipper do
   describe '.new' do
@@ -215,6 +216,31 @@ RSpec.describe Flipper do
     it 'delegates memoizing? to instance' do
       expect(described_class.memoizing?).to eq(described_class.adapter.memoizing?)
     end
+
+    it 'delegates sync stuff to instance and does nothing' do
+      expect(described_class.sync).to be(nil)
+      expect(described_class.sync_secret).to be(nil)
+    end
+
+    it 'delegates sync stuff to instance for Flipper::Cloud' do
+      stub = stub_request(:get, "https://www.flippercloud.io/adapter/features").
+        with({
+          headers: {
+            'Flipper-Cloud-Token'=>'asdf',
+          },
+        }).to_return(status: 200, body: '{"features": {}}', headers: {})
+      cloud_configuration = Flipper::Cloud::Configuration.new({
+        token: "asdf",
+        sync_secret: "tasty",
+      })
+
+      described_class.configure do |config|
+        config.default { Flipper::Cloud::DSL.new(cloud_configuration) }
+      end
+      described_class.sync
+      expect(described_class.sync_secret).to eq("tasty")
+      expect(stub).to have_been_requested
+    end
   end
 
   describe '.register' do
