@@ -1,3 +1,4 @@
+require 'climate_control'
 require 'json'
 require 'rack/test'
 
@@ -56,9 +57,33 @@ module SpecHelpers
       'more_info' => api_error_code_reference_url,
     }
   end
+
+  def with_modified_env(options, &block)
+    ClimateControl.modify(options, &block)
+  end
+
+  def silence
+    # Store the original stderr and stdout in order to restore them later
+    original_stderr = $stderr
+    original_stdout = $stdout
+
+    # Redirect stderr and stdout
+    output = $stderr = $stdout = StringIO.new
+
+    yield
+
+    $stderr = original_stderr
+    $stdout = original_stdout
+
+    # Return output
+    output.string
+  end
 end
 
 RSpec.configure do |config|
+  config.order = :random
+  Kernel.srand config.seed
+
   config.include Rack::Test::Methods
   config.include SpecHelpers
 end
